@@ -1,10 +1,10 @@
 package Class::C3::XS;
 
-use 5.006_000;
+use 5.008_000;
 use strict;
 use warnings;
 
-our $VERSION = '0.12_03';
+our $VERSION = '0.02';
 
 =pod
 
@@ -47,25 +47,4 @@ it under the same terms as Perl itself.
 require XSLoader;
 XSLoader::load('Class::C3::XS', $VERSION);
 
-$VERSION = eval $VERSION;
-
-package # hide me from PAUSE
-    next;
-
-sub can { Class::C3::XS::_nextcan($_[0], 0) }
-
-sub method {
-    my $method = Class::C3::XS::_nextcan($_[0], 1);
-    goto &$method;
-}
-
-package # hide me from PAUSE
-    maybe::next;
-
-sub method {
-    my $method = Class::C3::XS::_nextcan($_[0], 0);
-    goto &$method if defined $method;
-    return;
-}
-
 1;
